@@ -6,7 +6,7 @@ import time
 from collections import defaultdict
 from datetime import date
 from shutil import copyfileobj
-from typing import Any, Dict, Tuple, List, Optional, Any
+from typing import Any, Dict, Tuple, List, Optional, Union
 
 import pysam
 import requests
@@ -257,8 +257,7 @@ def _unique_RG_IDs_from_RG_tags(RG_ID_dict: dict, unique_RG_IDs: dict, alignment
     return RG_ID_dict, unique_RG_IDs
 
 
-def _extract_RG_info_from_long_read_input(long_read_input: List[str]) -> tuple[
-    Union[Union[str, bytes], Any], object, Optional[Any], Optional[Any], Optional[Any]]:
+def _extract_RG_info_from_long_read_input(long_read_input: List[str]) -> object:#tuple[Union[Union[str, bytes], Any], object, Optional[Any], Optional[Any], Optional[Any]]:
     """
 
     Returns:
